package com.fs.store.service.impl;

import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.fs.common.utils.DateUtils;
import com.fs.store.domain.FsCouponSchedule;
import com.fs.store.mapper.FsCouponScheduleMapper;
import com.fs.store.service.IFsCouponScheduleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 定时发放优惠券队列Service业务层处理
 *
 * @author fs
 * @date 2025-03-08
 */
@Service
public class FsCouponScheduleServiceImpl implements IFsCouponScheduleService
{
    @Autowired
    private FsCouponScheduleMapper fsCouponScheduleMapper;

    /**
     * 查询定时发放优惠券队列
     *
     * @param id 定时发放优惠券队列ID
     * @return 定时发放优惠券队列
     */
    @Override
    public FsCouponSchedule selectFsCouponScheduleById(Long id)
    {
        return fsCouponScheduleMapper.selectFsCouponScheduleById(id);
    }

    /**
     * 查询定时发放优惠券队列列表
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 定时发放优惠券队列
     */
    @Override
    public List<FsCouponSchedule> selectFsCouponScheduleList(FsCouponSchedule fsCouponSchedule)
    {
        return fsCouponScheduleMapper.selectFsCouponScheduleList(fsCouponSchedule);
    }

    /**
     * 新增定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    @Override
    public int insertFsCouponSchedule(FsCouponSchedule fsCouponSchedule)
    {
        fsCouponSchedule.setCreateTime(DateUtils.getNowDate());
        // 如果上次发送时间为空，那么预计发送时间等于=下单时间+1月
        if(ObjectUtil.isNull(fsCouponSchedule.getActualSendTime())){
            fsCouponSchedule.setSendTime(fsCouponSchedule.getOrderTime().plusMonths(1L));
        } else {
            // 否则等于上次发送时间+1月
            fsCouponSchedule.setSendTime(fsCouponSchedule.getActualSendTime().plusMonths(1L));
        }
        return fsCouponScheduleMapper.insertFsCouponSchedule(fsCouponSchedule);
    }

    /**
     * 修改定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    @Override
    public int updateFsCouponSchedule(FsCouponSchedule fsCouponSchedule)
    {
        fsCouponSchedule.setUpdateTime(DateUtils.getNowDate());
        return fsCouponScheduleMapper.updateFsCouponSchedule(fsCouponSchedule);
    }

    /**
     * 批量删除定时发放优惠券队列
     *
     * @param ids 需要删除的定时发放优惠券队列ID
     * @return 结果
     */
    @Override
    public int deleteFsCouponScheduleByIds(Long[] ids)
    {
        return fsCouponScheduleMapper.deleteFsCouponScheduleByIds(ids);
    }

    /**
     * 删除定时发放优惠券队列信息
     *
     * @param id 定时发放优惠券队列ID
     * @return 结果
     */
    @Override
    public int deleteFsCouponScheduleById(Long id)
    {
        return fsCouponScheduleMapper.deleteFsCouponScheduleById(id);
    }

    /**
     * 发放优惠券
     */
    @Override
    public void issueCoupon() {
        fsCouponScheduleMapper.selectPendingCouponList();
    }
}
